use actix_web::{web, Responder};
use askama::Template;
use chrono::{Months, Utc};
use sqlx::PgPool;

use crate::{
    filters,
    utils::{
        ApplicationError,
        DateTimeFormat::{DayMonthYearHourMinute, HourMinute, WeekdayDayMonthYear},
        TemplateResponse,
    },
};
use brass_db::models::{Assignment, Availability, Event, Function, Role, User};

#[derive(Template)]
#[template(path = "overview.html")]
struct OverviewTemplate {
    user: User,
    events: Vec<Event>,
    availabilities: Vec<Availability>,
}

#[actix_web::get("/")]
async fn get(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
) -> Result<impl Responder, ApplicationError> {
    let today = Utc::now().date_naive();
    let next_month = today.checked_add_months(Months::new(1)).unwrap();

    let events = Event::read_all_by_daterange_and_area_including_location(
        pool.get_ref(),
        (&today, &next_month),
        user.area_id,
    )
    .await?;

    let availabilities =
        Availability::read_by_user_and_daterange(pool.get_ref(), user.id, (&today, &next_month))
            .await?;

    let template = OverviewTemplate {
        user: user.into_inner(),
        events,
        availabilities,
    };

    Ok(template.to_response()?)
}
