use actix_web::{web, HttpResponse, Responder};
use sqlx::PgPool;

use crate::{
    endpoints::clothing::{NewOrEditClothingForm, ReadClothingPartialTemplate},
    utils::{ApplicationError, TemplateResponse},
};
use brass_db::models::{Clothing, Role, User};

#[actix_web::post("/clothing")]
pub async fn post(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
    form: web::Form<NewOrEditClothingForm>,
) -> Result<impl Responder, ApplicationError> {
    if user.role != Role::Admin {
        return Err(ApplicationError::Unauthorized);
    }

    if form.name.chars().count() < 3 {
        return Ok(HttpResponse::UnprocessableEntity().body("Name der Bekleidung ist zu kurz."));
    };

    let clothing = Clothing::create(pool.get_ref(), &form.name).await?;

    let template = ReadClothingPartialTemplate { c: clothing };

    Ok(template.to_response()?)
}
