use actix_web::{web, Responder};
use askama::Template;
use chrono::{NaiveDate, Utc};
use sqlx::PgPool;

use crate::utils::{ApplicationError, TemplateResponse};
use brass_db::models::{Area, Role, User};

#[derive(Template)]
#[template(path = "export/availability.html")]
struct AvailabilityExportTemplate {
    user: User,
    areas: Option<Vec<Area>>,
    today: NaiveDate,
}

#[actix_web::get("/export/availability")]
pub async fn get(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
) -> Result<impl Responder, ApplicationError> {
    if user.role != Role::Admin && user.role != Role::AreaManager {
        return Err(ApplicationError::Unauthorized);
    }

    let areas = if user.role == Role::Admin {
        Some(Area::read_all(pool.get_ref()).await?)
    } else {
        None
    };

    let template = AvailabilityExportTemplate {
        user: user.into_inner(),
        areas,
        today: Utc::now().date_naive(),
    };

    Ok(template.to_response()?)
}
