use actix_identity::Identity;
use actix_web::{http::header::LOCATION, web, HttpResponse, Responder};
use askama::Template;
use serde::Deserialize;

use crate::utils::{ApplicationError, TemplateResponse};

#[derive(Template)]
#[template(path = "user/login.html")]
struct LoginTemplate {
    next: Option<String>,
}

#[derive(Deserialize)]
struct LoginQuery {
    next: Option<String>,
}

#[actix_web::get("/login")]
async fn get(
    user: Option<Identity>,
    query: web::Query<LoginQuery>,
) -> Result<impl Responder, ApplicationError> {
    if user.is_some() {
        Ok(HttpResponse::Found()
            .insert_header((LOCATION, query.next.clone().unwrap_or("/".to_string())))
            .finish())
    } else {
        let template = LoginTemplate {
            next: query.next.clone(),
        };

        Ok(template.to_response()?)
    }
}
